# coding: utf-8

"""
    stylelens-feature

    This is a API document for Object Detection on fashion items\"

    OpenAPI spec version: 0.0.1
    Contact: devops@bluehack.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import stylelens_feature
from stylelens_feature.rest import ApiException
from stylelens_feature.models.box_object import BoxObject


class TestBoxObject(unittest.TestCase):
    """ BoxObject unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBoxObject(self):
        """
        Test BoxObject
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = stylelens_feature.models.box_object.BoxObject()
        pass


if __name__ == '__main__':
    unittest.main()
